@@ -17,6 +17,11 @@
 
 package org.apache.doris.spark.client.read;
 
+import org.apache.doris.sdk.thrift.TScanBatchResult;
+import org.apache.doris.spark.exception.DorisException;
+import org.apache.doris.spark.rest.models.Schema;
+import org.apache.doris.spark.util.IPUtils;
+
 import com.google.common.base.Preconditions;
 import org.apache.arrow.memory.RootAllocator;
 import org.apache.arrow.vector.BaseIntVector;
@@ -44,10 +49,6 @@ import org.apache.arrow.vector.ipc.ArrowReader;
 import org.apache.arrow.vector.ipc.ArrowStreamReader;
 import org.apache.arrow.vector.types.Types.MinorType;
 import org.apache.commons.lang3.ArrayUtils;
-import org.apache.doris.sdk.thrift.TScanBatchResult;
-import org.apache.doris.spark.exception.DorisException;
-import org.apache.doris.spark.rest.models.Schema;
-import org.apache.doris.spark.util.IPUtils;
 import org.apache.spark.sql.types.Decimal;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -64,7 +65,6 @@ import java.time.Instant;
 import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.ZoneId;
-import java.time.ZoneOffset;
 import java.time.format.DateTimeFormatter;
 import java.time.format.DateTimeFormatterBuilder;
 import java.time.temporal.ChronoField;
@@ -74,7 +74,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Objects;
-import java.util.TimeZone;
 
 /**
  * row batch data container.
@@ -266,7 +265,7 @@ public class RowBatch implements Serializable {
                                 byte[] bytes = largeIntVector.get(rowIndex);
                                 ArrayUtils.reverse(bytes);
                                 BigInteger largeInt = new BigInteger(bytes);
-                                addValueToRow(rowIndex, Decimal.apply(largeInt));
+                                addValueToRow(rowIndex, largeInt.toString());
                             }
                         } else {
                             VarCharVector largeIntVector = (VarCharVector) curFieldVector;
@@ -276,24 +275,24 @@ public class RowBatch implements Serializable {
                                     continue;
                                 }
                                 String stringValue = new String(largeIntVector.get(rowIndex));
-                                BigInteger largeInt = new BigInteger(stringValue);
-                                addValueToRow(rowIndex, Decimal.apply(largeInt));
+                                addValueToRow(rowIndex, stringValue);
                             }
                         }
                         break;
                     case "IPV4":
-                        Preconditions.checkArgument(mt.equals(MinorType.UINT4) || mt.equals(MinorType.INT),
+                        Preconditions.checkArgument(mt.equals(MinorType.UINT4) || mt.equals(MinorType.INT) || mt.equals(MinorType.VARCHAR),
                                 typeMismatchMessage(colName, currentType, mt));
-                        BaseIntVector ipv4Vector;
-                        if (mt.equals(MinorType.INT)) {
-                            ipv4Vector = (IntVector) curFieldVector;
+
+                        if (mt.equals(MinorType.VARCHAR)) {
+                            VarCharVector vector = (VarCharVector) curFieldVector;
+                            for (int i = 0; i < rowCountInOneBatch; i++) {
+                                addValueToRow(i, vector.isNull(i) ? null : new String(vector.get(i)));
+                            }
                         } else {
-                            ipv4Vector = (UInt4Vector) curFieldVector;
-                        }
-                        for (int rowIndex = 0; rowIndex < rowCountInOneBatch; rowIndex++) {
-                            Object fieldValue = ipv4Vector.isNull(rowIndex) ? null :
-                                    IPUtils.convertLongToIPv4Address(ipv4Vector.getValueAsLong(rowIndex));
-                            addValueToRow(rowIndex, fieldValue);
+                            BaseIntVector vector = (mt.equals(MinorType.INT)) ? (IntVector) curFieldVector : (UInt4Vector) curFieldVector;
+                            for (int i = 0; i < rowCountInOneBatch; i++) {
+                                addValueToRow(i, vector.isNull(i) ? null : IPUtils.convertLongToIPv4Address(vector.getValueAsLong(i)));
+                            }
                         }
                         break;
                     case "FLOAT":
@@ -348,6 +347,7 @@ public class RowBatch implements Serializable {
                     case "DECIMALV2":
                     case "DECIMAL32":
                     case "DECIMAL64":
+                    case "DECIMAL128":
                     case "DECIMAL128I":
                         Preconditions.checkArgument(mt.equals(MinorType.DECIMAL),
                                 typeMismatchMessage(colName, currentType, mt));
@@ -463,9 +463,15 @@ public class RowBatch implements Serializable {
                                 addValueToRow(rowIndex, null);
                                 break;
                             }
+                            // Compatible with IPv6  in Doris 2.1.3 and above.
                             String ipv6Str = new String(ipv6VarcharVector.get(rowIndex));
-                            String ipv6Address = IPUtils.fromBigInteger(new BigInteger(ipv6Str));
-                            addValueToRow(rowIndex, ipv6Address);
+                            if (ipv6Str.contains(":")){
+                                addValueToRow(rowIndex, ipv6Str);
+                            }else {
+                                String ipv6Address = IPUtils.fromBigInteger(new BigInteger(ipv6Str));
+                                addValueToRow(rowIndex, ipv6Address);
+                            }
+
                         }
                         break;
                     case "ARRAY":
