@@ -30,6 +30,7 @@ import org.apache.spark.sql.util.CaseInsensitiveStringMap
 
 import java.util
 import scala.collection.JavaConverters._
+import scala.collection.mutable
 import scala.language.implicitConversions
 
 
@@ -45,11 +46,17 @@ abstract class DorisTableBase(identifier: Identifier, config: DorisConfig, schem
   })
 
   override def capabilities(): util.Set[TableCapability] = {
-    Set(BATCH_READ,
+    val capabilities = mutable.Set(BATCH_READ,
       BATCH_WRITE,
       STREAMING_WRITE,
-      ACCEPT_ANY_SCHEMA,
-      TRUNCATE).asJava
+      TRUNCATE)
+    val properties = config.getSinkProperties
+    val partialColumnsEnabled = properties.containsKey(DorisOptions.PARTIAL_COLUMNS) && "true".equalsIgnoreCase(properties.get(DorisOptions.PARTIAL_COLUMNS))
+    val schemaLessEnabled = config.getValue(DorisOptions.DORIS_WRITE_SCHEMA_LESS)
+    if (partialColumnsEnabled || schemaLessEnabled) {
+      capabilities += ACCEPT_ANY_SCHEMA
+    }
+    capabilities.asJava
   }
 
   override def newScanBuilder(caseInsensitiveStringMap: CaseInsensitiveStringMap): ScanBuilder = {
